@@ -1,8 +1,8 @@
-/*  $Id: main-window.cpp,v 1.38 2011/01/25 02:29:43 sarrazip Exp $
+/*  $Id: main-window.cpp,v 1.42 2013/06/28 18:12:03 sarrazip Exp $
     main-window.cpp - Input and conjugation window
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2010 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2013 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -16,8 +16,8 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-    02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #include "main-window.h"
@@ -42,6 +42,7 @@
 #include <iostream>
 #include <fstream>
 #include <sstream>
+#include <iomanip>  /* for setw() */
 #include <algorithm>
 
 #define _(x) gettext(x)
@@ -117,6 +118,9 @@ public:
     ResultPage();
 
     // No destructor because this object does not own the two GtkWidgets.
+
+    void enableLinkButton(const string &utf8Infinitive);
+
 };
 
 
@@ -138,6 +142,44 @@ ResultPage::ResultPage()
 }
 
 
+// Converts the given UTF-8 string to an ASCII-only string where any
+// non-ASCII character is represented by a %HH sequence where HH is
+// the 2-digit hexadecimal Unicode number of the non-ASCII character.
+// Example: "bébé" becomes "b%e9b%e9".
+//
+static string
+convertUTF8ToPercentHex(const char *utf8)
+{
+    stringstream result;
+    result << hex;
+    for (const char *p = utf8; *p != '\0'; p = g_utf8_next_char(p))
+    {
+        gunichar c = g_utf8_get_char(p);
+        if (c <= 127)  // if ASCII
+            result << char(c);
+        else
+            result << '%' << setw(2) << c;
+    }
+    return result.str();
+}
+
+
+// Adds a link to the table that points to a web page that defines the verb.
+//
+void
+ResultPage::enableLinkButton(const string &utf8Infinitive)
+{
+    string uri = "http://fr.wiktionary.org/wiki/"
+                    + convertUTF8ToPercentHex(utf8Infinitive.c_str());
+    GtkWidget *linkButton = gtk_link_button_new_with_label(
+                                uri.c_str(), _("Look up on Wiktionnaire"));
+    gtk_table_attach(GTK_TABLE(table), linkButton,
+                        1, 3, 0, 1,
+                        GTK_SHRINK, GTK_SHRINK,
+                        8, 8);
+}
+
+
 /*****************************************************************************/
 
 
@@ -941,8 +983,6 @@ showResultWin()
         // Provide buttons that add accented characters to the Verb text field.
         // The \x codes are in UTF-8.
         //
-        //GtkWidget *nameLabel = newLabel(_("Accented characters:"), FALSE, 0.5);
-        //gtk_box_pack_start(GTK_BOX(optionsBox), nameLabel, FALSE, FALSE, 0);
         addAccentedCharButton(optionsBox, "\xc3\xa0"); // in HTML: &agrave;
         addAccentedCharButton(optionsBox, "\xc3\xa2"); // in HTML: &acirc;
         addAccentedCharButton(optionsBox, "\xc3\xa7"); // in HTML: &ccedil;
@@ -1096,8 +1136,7 @@ createTableCell(const VVS &utf8Tense,
                 FrenchVerbDictionary *fvd)
 {
     GtkWidget *vbox = gtk_vbox_new(FALSE, SP);
-    GtkWidget *nameLabel = newLabel(
-                            "<b><u>" + utf8TenseName + "</u></b>", TRUE);
+    GtkWidget *nameLabel = newLabel("<b><u>" + utf8TenseName + "</u></b>", TRUE);
 
     string utf8Persons = createTableCellText(
                                 *fvd,
@@ -1246,6 +1285,9 @@ deconjugate(FrenchVerbDictionary &fvd, const string &utf8UserText,
 
         string label = utf8Infinitive + " (" + FrenchVerbDictionary::getLanguageCode(fvd.getLanguage()) + ")";
         ResultPage *rp = appendResultPage(label);
+
+        rp->enableLinkButton(utf8Infinitive);
+
         numPages++;
 
         int i = 0;
@@ -1426,8 +1468,7 @@ finishProcessingText(const string &utf8UserText, size_t numPages)
 {
     if (numPages == 0 && !utf8UserText.empty())
     {
-        ResultPage *rp = appendResultPage(
-                                        "<i>" + string(_("error")) + "</i>");
+        ResultPage *rp = appendResultPage("<i>" + string(_("error")) + "</i>");
         GtkWidget *cell = newLabel(_("Unknown verb."), FALSE);
         gtk_table_attach(GTK_TABLE(rp->table), cell,
                                 0, 1, 0, 1,
