@@ -12,15 +12,17 @@ initDictPointers()
 
     try
     {
+        using namespace verbiste;
+
         // Initialize global dictionary pointers.
         string conjFN, verbsFN;
-        verbiste::FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, "fr");
+        FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, FrenchVerbDictionary::FRENCH);
         //cout << "fr: '" << conjFN << "', '" << verbsFN << "'\n";
-        frenchDict = new verbiste::FrenchVerbDictionary(conjFN, verbsFN, true, "fr");  // may throw
+        frenchDict = new FrenchVerbDictionary(conjFN, verbsFN, true, FrenchVerbDictionary::FRENCH);  // may throw
 
-        verbiste::FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, "it");
+        FrenchVerbDictionary::getXMLFilenames(conjFN, verbsFN, FrenchVerbDictionary::ITALIAN);
         //cout << "it: '" << conjFN << "', '" << verbsFN << "'\n";
-        italianDict = new verbiste::FrenchVerbDictionary(conjFN, verbsFN, true, "it");  // may throw
+        italianDict = new FrenchVerbDictionary(conjFN, verbsFN, true, FrenchVerbDictionary::ITALIAN);  // may throw
         return string();  // success
     }
     catch(logic_error &e)
